@@ -33,3 +33,8 @@ KIBANA_SEED_COLORS = [
     "#daa05d",
     "#00a69b",
 ]
+
+DEFAULT_WIDTH = 800
+DEFAULT_PIE_WIDTH = 200
+DEFAULT_HEIGHT = 200
+DEFAULT_PADDING = 5
